# [Slither, the smart contract static analyzer](https://crytic.github.io/slither/slither.html)

<img src="https://raw.githubusercontent.com/crytic/slither/master/logo.png" alt="Slither Static Analysis Framework Logo" width="500" />

[**Slither**](https://github.com/crytic/slither) is a Solidity & Vyper static analysis framework written in Python3. It runs a suite of vulnerability detectors, prints visual information about contract details, and provides an API to easily write custom analyses. Slither enables developers to find vulnerabilities, enhance their code comprehension, and quickly prototype custom analyses.

If you are looking to use Slither's cli:

- [Usage](./Usage.md) the most common flags

If you are looking to leverage Slither inbuilt features:

- [Detectors](./detectors/): Vulnerabilities detectors
- [Printers](./printers): Printers (code vizualiation)
- [Tools](./tools): Custom tools

If you are looking to learn how to extend Slither's capabilities:

- [API](./api): Introduction to static analysis & Slither's API
- [Tutorial](./tutorials/): Hands-on exercises
